## Introduction

If you're not familiar with the popular Dino Chrome game which surprisingly eases tension during a marathon coding session, you might be living under a rock. However, I'd like to introduce you to Dino-Terminal. Don't worry too much, you guessed right: It's the same Dino game (with more features) but in the terminal. 

Dino-Terminal is a simple dino game that is built on your terminal.
Here's what we don't want: The common dino longing for an affection outside Chrome.

| <img width="178" alt="Screenshot 2023-12-12 at 22 13 07" src="https://github.com/nelsonifechukwu/dino-terminal/assets/44223263/8c91e7db-9587-4e44-b863-e977f7481bdb">  | <img width="179" alt="Screenshot 2023-12-12 at 22 11 18" src="https://github.com/nelsonifechukwu/dino-terminal/assets/44223263/fc59de75-1104-47f1-b9f8-b4e17fd75b66"> |
:--------:|:--------:
![cdino](https://github.com/nelsonifechukwu/dino-terminal/assets/44223263/1083a758-3b4f-4b84-b2a6-27dbd4a82335)  |  ![dino](https://github.com/nelsonifechukwu/dino-terminal/assets/44223263/4c0001bd-9263-4c53-bb75-b3b88b65aeb1)

## Installation
To install, simply ```pip install dino-terminal``` 

## How to play the game
- Usage: ```dino-terminal```
- Press the space bar key to jump over obstacles

## Possible Updates
This project is fun to learn about manipulating strings on the terminal and is based on the curses library. Here are some possible updates to improve the game:

- Include easter eggs.
- Include randomly generated flying birds to duck below.
- Train an AI model to successfully play the game without losing.
- Pull requests are welcomed 😁

